@@ -1,6 +1,6 @@
 package Poet::Script;
 BEGIN {
-  $Poet::Script::VERSION = '0.04';
+  $Poet::Script::VERSION = '0.05';
 }
 use Cwd qw(realpath);
 use File::Basename;
@@ -19,39 +19,34 @@ method import ($pkg:) {
     Poet::Environment->current_env->importer->export_to_level( 1, @_ );
 }
 
-func initialize_with_root_dir($root_dir) {
-    my $lib_dir = "$root_dir/lib";
-      unless ( $INC[0] eq $lib_dir ) {
-        unshift( @INC, $lib_dir );
-    }
-
+func initialize_with_root_dir ($root_dir) {
     my ($app_name) = ( read_file("$root_dir/.poet_root") =~ /app_name: (.*)/ )
       or die "cannot find app_name in $root_dir/.poet_root";
 
-      return Poet::Environment->initialize_current_environment(
+    return Poet::Environment->initialize_current_environment(
         root_dir => $root_dir,
         app_name => $app_name
-      );
-  }
+    );
+}
 
-  func determine_root_dir() {
+func determine_root_dir () {
 
     # Search for .poet_root upwards from current directory, using rel2abs
     # first, then realpath.
     #
-    my $path1      = dirname( rel2abs($0) );
-      my $path2    = dirname( realpath($0) );
-      my $root_dir = search_upward($path1) || search_upward($path2);
-      unless ( defined $root_dir ) {
+    my $path1    = dirname( rel2abs($0) );
+    my $path2    = dirname( realpath($0) );
+    my $root_dir = search_upward($path1) || search_upward($path2);
+    unless ( defined $root_dir ) {
         die sprintf( "could not find .poet_root upwards from %s",
             ( $path1 eq $path2 ) ? "'$path1'" : "'$path1' or '$path2'" );
     }
     return $root_dir;
-  }
+}
 
-  func search_upward($path) {
+func search_upward ($path) {
     my $count = 0;
-      while ( realpath($path) ne '/' && $count++ < 10 ) {
+    while ( realpath($path) ne '/' && $count++ < 10 ) {
         if ( -f "$path/.poet_root" ) {
             return realpath($path);
             last;
@@ -59,9 +54,9 @@ func initialize_with_root_dir($root_dir) {
         $path = dirname($path);
     }
     return undef;
-  }
+}
 
-  1;
+1;
 
 
 __END__
