@@ -2,10 +2,11 @@
 #
 package Poet::Tools;
 BEGIN {
-  $Poet::Tools::VERSION = '0.04';
+  $Poet::Tools::VERSION = '0.05';
 }
 use Carp;
 use Class::MOP;
+use Config;
 use Fcntl qw( :DEFAULT :seek );
 use File::Find;
 use File::Spec::Functions ();
@@ -16,7 +17,7 @@ use warnings;
 use base qw(Exporter);
 
 our @EXPORT_OK =
-  qw(can_load catdir catfile checksum find_wanted read_file taint_is_on tempdir_simple trim uniq write_file );
+  qw(can_load catdir catfile checksum find_wanted perl_executable read_file taint_is_on tempdir_simple trim uniq write_file );
 
 my $Fetch_Flags          = O_RDONLY | O_BINARY;
 my $Store_Flags          = O_WRONLY | O_CREAT | O_BINARY;
@@ -81,6 +82,19 @@ sub find_wanted {
     return @files;
 }
 
+# Return perl executable - from ExtUtils::MM_Unix
+sub perl_executable {
+    my $interpreter;
+    if ( $Config{startperl} =~ m,^\#!.*/perl, ) {
+        $interpreter = $Config{startperl};
+        $interpreter =~ s,^\#!,,;
+    }
+    else {
+        $interpreter = $Config{perlpath};
+    }
+    return $interpreter;
+}
+
 sub read_file {
     my ($file) = @_;
 
